@@ -42,15 +42,12 @@ class RestApplication(object):
         urls = self.url_map.bind_to_environ(request.environ)
 
         # Attempt to process pre-request hooks.
-        print "PROCESSING REQUEST HOOKS"
         try:
 
             request = self.process_request_hooks(request)
 
         except HTTPException as e:
 
-            print "REQUEST HOOK HTTP EXCEPTION"
-
             response = e
 
             response = self.process_response_hooks(request, response)
@@ -59,8 +56,6 @@ class RestApplication(object):
 
         except Exception as e:
 
-            print "REQUEST HOOK PY EXCEPTION"
-
             response = InternalServerError(description=unicode(e))
 
             response = self.process_response_hooks(request, response)
@@ -71,32 +66,27 @@ class RestApplication(object):
         # variable is captialzied.
         # This call automatically raises a `NotFound` exception if there is no
         # match found.
-        print "MATCHING URLS"
+
         try:
 
             Endpoint, kwargs = urls.match()
 
         except HTTPException as e:
 
-            print "URL HTTP EXCEPTION"
-
             response = e
 
-            print "PROCESSING RESPONSE HOOKS"
             response = self.process_response_hooks(request, response)
 
             return response
 
         handler_endpoint = Endpoint()
 
-        print "FINDING METHOD"
         try:
 
             handler_method = getattr(handler_endpoint, verb)
 
         except AttributeError:
 
-            print "METHOD NOT FOUND"
             # If method not found then generate a list of allowed methods.
             # The list of allowed methods is required to satisfy the HTTP
             # standard for Method Now Allowed. Currently only matches GET,
@@ -111,29 +101,22 @@ class RestApplication(object):
                                                            ]
                                                        ])
 
-            print "PROCESSING POST HOOKS"
             response = self.process_response_hooks(request, response)
 
             return response
 
-        print "EXECUTING METHOD"
         try:
 
             response = handler_method(request, **kwargs)
 
         except HTTPException as e:
 
-            print "EXECUTION WAS HTTP EXCEPTION"
-
             response = e
 
         except Exception as e:
 
-            print "EXECUTION WAS PY EXCEPTION"
-
             response = InternalServerError(description=unicode(e))
 
-        print "PROCESSING RESPONSE HOOKS"
         response = self.process_response_hooks(request, response)
 
         return response
