@@ -1,7 +1,7 @@
 from werkzeug.test import EnvironBuilder
-from werkzeug.wrappers import Response, Request
+from werkzeug.wrappers import Response
 from werkzeug.routing import Map, Rule
-from werkzeug.exceptions import MethodNotAllowed, NotFound
+from werkzeug.exceptions import MethodNotAllowed, NotFound, BadRequest
 
 import unittest
 
@@ -14,6 +14,10 @@ class TestEndpoint(object):
 
         return Response("TEST")
 
+    def POST(self, request):
+
+        raise BadRequest("TEST")
+
 
 test_ulrs = Map([
     Rule('/', endpoint=TestEndpoint)
@@ -38,17 +42,23 @@ class TestApplication(unittest.TestCase):
 
     def test_verb_routing_failure(self):
 
-        try:
-            environ = EnvironBuilder(path='/', method='POST').get_environ()
-            self.application(environ, lambda: None)
-        except MethodNotAllowed:
-            return
+        environ = EnvironBuilder(path='/', method='PUT').get_environ()
+        response = self.application(environ, lambda: None)
+
+        self.assertTrue(isinstance(response, MethodNotAllowed))
 
     def test_route_not_found(self):
 
-        try:
-            environ = EnvironBuilder(path='/notfound',
-                                     method='GET').get_environ()
-            self.application(environ, lambda: None)
-        except NotFound:
-            return
+        environ = EnvironBuilder(path='/notfound',
+                                 method='GET').get_environ()
+        response = self.application(environ, lambda: None)
+
+        self.assertTrue(isinstance(response, NotFound))
+
+    def test_application_raises_exception(self):
+
+        environ = EnvironBuilder(path='/',
+                                 method='POST').get_environ()
+        response = self.application(environ, lambda: None)
+
+        self.assertTrue(isinstance(response, BadRequest))
