@@ -31,10 +31,10 @@ class TestRouting(unittest.TestCase):
 
     def test_uuid_routing_success(self):
 
-        request = Request(EnvironBuilder(path='/' + str(uuid.uuid4()),
-                                         method='GET').get_environ())
+        environ = EnvironBuilder(path='/' + str(uuid.uuid4()),
+                                 method='GET').get_environ()
 
-        response = self.application(request)
+        response = self.application(environ, lambda: None)
 
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response.data, "TEST")
@@ -42,8 +42,7 @@ class TestRouting(unittest.TestCase):
     def test_uuid_routing_failure(self):
 
         try:
-            request = Request(EnvironBuilder(path='/',
-                                             method='POST').get_environ())
-            self.application(request)
+            environ = EnvironBuilder(path='/', method='POST').get_environ()
+            self.application(environ, lambda: None)
         except NotFound:
             return
