@@ -7,7 +7,6 @@ import unittest
 
 from restpy.applications import RestApplication
 from restpy.wsgi import UniqueEnvironMiddleware
-from restpy.wsgi import ExceptionHandlerMiddleware
 from restpy.wsgi import ResponderMiddleware
 
 
@@ -81,28 +80,3 @@ class TestResponderMiddleware(unittest.TestCase):
         response = self.application(environ, start_response)
 
         iter(response)
-
-
-class TestExceptionHandlerMiddleware(unittest.TestCase):
-
-    def setUp(self, *args, **kwargs):
-
-        super(TestExceptionHandlerMiddleware, self).setUp(*args, **kwargs)
-        self.application = RestApplication(test_ulrs)
-        self.application = ExceptionHandlerMiddleware(self.application)
-
-    def test_catches_method_exceptions(self):
-
-        environ = EnvironBuilder(path='/', method='POST').get_environ()
-
-        response = self.application(environ, lambda: None)
-
-        self.assertTrue(isinstance(response, BadRequest))
-
-    def test_catches_routing_exceptions(self):
-
-        environ = EnvironBuilder(path='/', method='DELETE').get_environ()
-
-        response = self.application(environ, lambda: None)
-
-        self.assertTrue(isinstance(response, MethodNotAllowed))
